clear all;
%****************************************
% here we compute the transition probability for the process tilde Y from the example in Section 4.2
% the process Y is the Brownian motion on (0,infty) killed at zero
%****************************************
syms t x y Phi u hx hy lambda mh f1 f2 p C;
lambda=1/2;
mh=0;
assume(t>0);
Phi=(1+erf(u/sqrt(2)))/2; % the CDF of standard normal distribution
hy=(exp(y)-exp(-y))/2;    % lambda-invariant function h(y)=sinh(y)
%****************************************
 % transition probability of Y
p=(exp(-(y-x)^2/(2*t))-exp(-(y+x)^2/(2*t)))/sqrt(2*pi*t); 
%****************************************
% transition probability of tilde Y
hx=subs(hy,y,x);
tilde_p1=exp(-t)*(exp(-(y-x)^2/(2*t))+exp(-(y+x)^2/(2*t)))/sqrt(2*pi*t)...
    +(exp(-t/2)/(2*hx*hy))*(subs(Phi,u,(y-x-t)/sqrt(t))+subs(Phi,u,(y+x+t)/sqrt(t))-subs(Phi,u,(y+x-t)/sqrt(t))-subs(Phi,u,(y-x+t)/sqrt(t)))
%****************************************
% compute transition probability of tilde Y via Theorem 2
f1=simplify(int(p*hy,y)); % this computes the indefinte integral of p_t(x,u)h(u)du
f2=(simplify(limit(f1,y,inf)-f1)); % this computes the definite integral from y to r of p_t(x,u)h(u)du
tilde_p2=simplify(exp(-(mh+2*lambda)*t)*(hx/hy)*diff(f2/hx,x,1))  %this computes the transition probability density of tilde Y
%****************************************
% now we compare tilde_p1 and tilde_p2
difference_between_two_expressions=simplify(expand(tilde_p1-tilde_p2),'Steps',150)
if (difference_between_two_expressions==0)
    disp('formula successfully verified');
end


