clear all;
%****************************************
% here we check the formula for the transition probability for the process tilde Y from the example in Section 4.3
% Y is the Brownian motion on (0,inf) with elastic boundary condition at zero f'(0+)=gamma f(0+)
%****************************************
syms t x y Phi u hx hy gamma beta;
lambda=1/2;
mh=0;
Phi=(1+erf(u/sqrt(2)))/2; % the CDF of standard normal distribution
beta=(1-gamma)/(1+gamma);
hx=exp(x)+beta*exp(-x);  % lambda-invariant function for Y
hy=subs(hx,x,y);
assume(t>0);
assume(gamma>0);
%****************************************
% transition probability of Y
p=(exp(-(y-x)^2/(2*t))+exp(-(y+x)^2/(2*t)))/sqrt(2*pi*t)-2*gamma*exp(gamma*(x+y)+gamma^2*t/2)*subs(Phi,u,-(y+x+gamma*t)/sqrt(t));
% transition probability of tilde Y 
tilde_p1=(exp(-t)/sqrt(2*pi*t))*(exp(-(y-x)^2/(2*t))-exp(-(y+x)^2/(2*t)))...
    -8*gamma*beta*(sinh(x)*sinh(y)/(hx*hy))*exp(gamma*(x+y)+(gamma^2/2-1)*t)*(subs(Phi,u,-(y+x+gamma*t)/sqrt(t)))...
    +(2*beta*exp(-t/2)/(hx*hy))*(subs(Phi,u,(y+x-t)/sqrt(t))-subs(Phi,u,(y+x+t)/sqrt(t))+subs(Phi,u,(y-x+t)/sqrt(t))-subs(Phi,u,(y-x-t)/sqrt(t)));
%****************************************
% we define f1 to be the following function
f1=((exp(2*y)-1)*gamma*(erf((sqrt(2)*(x/2+(t*gamma)/2+y/2))/sqrt(t))-1)*exp(gamma*x+(t*gamma^2)/2+y*gamma-y))/(gamma+1);
% the limit of f1 as y goes to +infty is zero, as f1 can be written as a sum of terms
% (erf(a+b*y)-1)*exp(A+B*y) for b=1/sqrt(2*t) 
% and each of these terms goes to zero as y -> +infty
% this last statement is true due to the asymptotic result 
% 1-erf(u)=exp(-u^2)/(u*sqrt(pi))(1+o(1)) as u-> +infty
%*****************************************
% compute transition probability of tilde Y via Theorem 2
f=simplify(int(p*hy,y))  % this computes the indefinte integral of p_t(x,u)h(u)du
f2=simplify(expand(f-f1));
% the limit of f as y->+ifty is equal to the limit of f2 (since the limit of f1 is zero)
% and we can proceed with computing the transition probability of tilde Y:
f=simplify((limit(f2,y,inf)-f)/hx);
tilde_p2=simplify(exp(-(mh+2*lambda)*t)*(hx/hy)*diff(f,x,1))
%****************************************
% now we compare tilde_p1 and tilde_p2
difference_between_two_expressions=simplify(expand(tilde_p1-tilde_p2),'Steps',150)
if (difference_between_two_expressions==0)
    disp('formula successfully verified');
end



