clear all;
%****************************************
% here we check the formula for the transition probability for the process tilde Y from the example in Section 4.5
% Y is the Brownian motion on R killed at rate y^2/2
%****************************************
syms t x y u hx hy A B C pi;
hx=exp(x^2/2)*(2*x^2+1);  % lambda-invariant function for Y
hy=subs(hx,x,y);
assume(t>0);
assume(B>0);
%****************************************
% transition probability of Y
p=A*exp(-(1+B)/2*(x^2+y^2)+C*x*y);
% transition probability of tilde Y 
tilde_p1=p*exp(-4*t)*(1+(4*sinh(t)*(exp(t)-2*x*y))/((2*x^2 + 1)*(2*y^2 + 1)));
%****************************************
% compute transition probability of tilde Y via Theorem 2
f=simplify(int(p*hy,y));  % this computes the indefinte integral of p_t(x,u)h(u)du
f=simplify(expand(simplify(limit(f,y,inf)))-f);
f=simplify(f/hx);
tilde_p2=exp(-5*t)*simplify((hx/hy)*diff(f,x,1));
%****************************************
% replace A,B,C by their proper values
tilde_p1=subs(tilde_p1,A,1/sqrt(pi*(exp(t)-exp(-t))));
tilde_p1=subs(tilde_p1,B,2/(exp(2*t)-1));
tilde_p1=subs(tilde_p1,C,2*exp(t)/(exp(2*t)-1));
tilde_p2=subs(tilde_p2,A,1/sqrt(pi*(exp(t)-exp(-t))));
tilde_p2=subs(tilde_p2,B,2/(exp(2*t)-1));
tilde_p2=subs(tilde_p2,C,2*exp(t)/(exp(2*t)-1))
%****************************************
F=(tilde_p1-tilde_p2)*(2*x^2+1)*(2*y^2+1);
difference_between_two_expressions=simplify(expand(F),'Steps',150)
if (difference_between_two_expressions==0)
    disp('formula successfully verified');
end



